@@ -36,10 +36,10 @@ FTPFtwTraverse(const FtwInfoPtr ftwip, size_t dirPathLen, int depth)
 	int rc = (-1);
 	int lsl, mls, unlsrc;
 	FTPCIPtr cip = (FTPCIPtr) ftwip->cip;
-	LineList ll;
-	FileInfoList fil;
-	LinePtr filePtr;
-	FileInfoPtr fip;
+	FTPLineList ll;
+	FTPFileInfoList fil;
+	FTPLinePtr filePtr;
+	FTPFileInfoPtr fip;
 	int result;
 	int isRootDir;
 	longest_int sz;
@@ -50,7 +50,7 @@ FTPFtwTraverse(const FtwInfoPtr ftwip, size_t dirPathLen, int depth)
 	mls = 0;
 	lsl = 0;
 
-	if (cip->hasMLSD) {
+	if (cip->hasMLSD == kCommandAvailable) {
 		mls = 1;
 		if (((result = FTPListToMemory2(cip, dirPathLen ? path : ".", &ll, "-a", 0, &mls)) < 0) || (ll.first == NULL)) {
 			/* Not an error unless the first directory could not be opened. */
@@ -59,10 +59,10 @@ FTPFtwTraverse(const FtwInfoPtr ftwip, size_t dirPathLen, int depth)
 		}
 
 		/* "MLSD" succeeded */
-		unlsrc = UnMlsD(&fil, &ll);
+		unlsrc = UnMlsD(cip, &fil, &ll);
 		if (unlsrc < 0) {
 			DisposeLineListContents(&ll);
-			return (kErrInvalidMLSTResponse);
+			return (cip->errNo = kErrInvalidMLSTResponse);
 		} else if (unlsrc == 0) {
 			/* empty */
 			DisposeLineListContents(&ll);
@@ -73,21 +73,21 @@ FTPFtwTraverse(const FtwInfoPtr ftwip, size_t dirPathLen, int depth)
 	} else {
 		if (((result = FTPListToMemory2(cip, dirPathLen ? path : ".", &ll, "-la", 0, &mls)) < 0) || (ll.first == NULL)) {
 			DisposeLineListContents(&ll);
-			if (((result = FTPListToMemory2(cip, dirPathLen ? path : ".", &ll, "-a", 0, &mls)) < 0) || (ll.first == NULL)) {
+			if (((result = FTPListToMemory2(cip, dirPathLen ? path : ".", &ll, (cip->hasNLST_a == kCommandNotAvailable) ? "" : "-a", 0, &mls)) < 0) || (ll.first == NULL)) {
 				DisposeLineListContents(&ll);
 				return (0);
 			} else {
 				/* "NLST -a" succeeded */
-				RemoteGlobCollapse(path, &ll);
+				RemoteGlobCollapse(cip, path, &ll);
 				filePtr = ll.first;
 			}
 		} else {
 			/* "LIST -a" succeeded */
 			lsl = 1;
-			unlsrc = UnLslR(&fil, &ll, cip->serverType);
+			unlsrc = UnLslR(cip, &fil, &ll, cip->serverType);
 			if (unlsrc < 0) {
 				DisposeLineListContents(&ll);
-				return (kErrInvalidMLSTResponse);
+				return (cip->errNo = kErrInvalidMLSTResponse);
 			} else if (unlsrc == 0) {
 				/* empty */
 				DisposeLineListContents(&ll);
