@@ -13,7 +13,12 @@
 struct tm *
 Localtime(time_t t, struct tm *const tp)
 {
-#if defined(HAVE_LOCALTIME_R) && !defined(MACOSX)
+#if defined(HAVE_LOCALTIME_R) && (defined(HPUX)) && (HPUX < 1100)
+	if (t == 0)
+		time(&t);
+	if (localtime_r(&t, tp) == 0)
+		return (tp);
+#elif defined(HAVE_LOCALTIME_R) && !defined(MACOSX)
 	if (t == 0)
 		time(&t);
 	if (localtime_r(&t, tp) != NULL)
